@@ -1,14 +1,18 @@
-from .base import GeneratedItem, KeyShortcut, Literal, Action, NSApp, const, convertValueToObjc
+from .base import GeneratedItem, NSApp, const, convertValueToObjc
+from .types import Action
+from .property import ImageProperty, ActionProperty, KeyShortcutProperty
 
 class MenuItem(GeneratedItem):
     OBJC_CLASS = 'NSMenuItem'
+    PROPERTIES = GeneratedItem.PROPERTIES + [
+        'tag', 'hidden', ImageProperty('image'), ActionProperty('action'),
+        KeyShortcutProperty('shortcut')
+    ]
     
     def __init__(self, name, action=None, shortcut=None, tag=None):
         GeneratedItem.__init__(self)
         self.name = name
         self.action = action
-        if shortcut and not isinstance(shortcut, KeyShortcut):
-            shortcut = KeyShortcut(shortcut)
         self.shortcut = shortcut
         self.tag = tag
     
@@ -16,23 +20,10 @@ class MenuItem(GeneratedItem):
         tmpl = GeneratedItem.generateInit(self)
         if self.name == "-":
             tmpl.allocinit = "[$menuname$ addItem:[NSMenuItem separatorItem]];\n"
-            tmpl.setup = ""
         else:
-            tmpl.allocinit = "NSMenuItem *$varname$ = [$menuname$ addItemWithTitle:$name$ action:nil keyEquivalent:@\"$key$\"];"
-            tmpl.setup = "$linkaction$"
+            tmpl.allocinit = "NSMenuItem *$varname$ = [$menuname$ addItemWithTitle:$name$ action:nil keyEquivalent:@\"\"];"
         tmpl.name = convertValueToObjc(self.name)
         tmpl.menuname = menuname
-        if self.action:
-            tmpl.linkaction = self.action.generate(self.varname)
-        else:
-            tmpl.linkaction = ''
-        if self.shortcut:
-            tmpl.key = self.shortcut.key
-            if self.shortcut.flags:
-                self.properties['keyEquivalentModifierMask'] = Literal(self.shortcut.flags)
-        else:
-            tmpl.key = "nil"
-        self.properties['tag'] = self.tag
         return tmpl
     
 
